@@ -44,7 +44,8 @@ RcppExport SEXP cvEMlassoMain( SEXP data, SEXP response
     lambdaC.resize(100);
     //corrMax is the first lambda value in the lars sequence
     STK::Real corrMax = (x.transpose() * y).abs().maxElt();
-    STK::Real gapLambda = (log(corrMax)-log(corrMax * (n<p) ? 0.01 : 0.0001))/99;
+    double ratio = (n<p) ? 0.01 : 0.0001;
+    STK::Real gapLambda = (log(corrMax)-log(corrMax * ratio))/99;
     lambdaC[99] = corrMax;
     for(int i = 99; i>0 ; i--)
       lambdaC[i-1] = exp(log(lambdaC[i]) - gapLambda);
